% Generated by roxygen2 (4.1.1): do not edit by hand
% Please edit documentation in R/support.export.R
\name{brm.pars}
\alias{brm.pars}
\title{Parameters of interest for \code{brms} models}
\usage{
brm.pars(formula, data = NULL, family = "gaussian", partial = NULL,
  threshold = "flexible", post.pred = FALSE, reffects = FALSE,
  engine = "stan", ...)
}
\arguments{
\item{formula}{An object of class "formula" (or one that can be coerced to that class): a symbolic description of the model to be fitted.
The details of model specification are given under 'Details'.}

\item{data}{An optional data frame, list or environment  (or object coercible by \code{as.data.frame} to a data frame) containing
the variables in the model. If not found in data, the variables are taken from \code{environment(formula)},
typically the environment from which \code{brm} is called.}

\item{family}{A vector of one or two character strings. The first string indicates the distribution of the dependent variable (the 'family'). Currently, the following families are supported:
\code{"gaussian"}, \code{"student"}, \code{"cauchy"}, \code{"poisson"}, \code{"binomial"}, \code{"categorical"}, \code{"gamma"}, \code{"exponential"},
\code{"weibull"}, \code{"cumulative"}, \code{"cratio"}, \code{"sratio"}, and \code{"acat"}.
The second string indicates the link function, which must be supported by the distribution of the dependent variable.
If not specified, default link functions are used. Further information is provided under 'Details'.}

\item{partial}{A one sided formula of the form \code{~ partial.effects} specifing the predictors that can vary between categories in non-cumulative ordinal models
(i.e. in families \code{"cratio"}, \code{"sratio"}, or \code{"acat"}).}

\item{threshold}{A character string indicating the type of thresholds (i.e. intercepts) used in an ordinal model.
\code{"flexible"} provides the standard unstructured thresholds and \code{"equidistant"} restricts the distance between consecutive thresholds to the same value.}

\item{post.pred}{A flag to indicate if posterior predictives of the dependent variables should be generated}

\item{reffects}{logical; indicating wheter random effects estimates should be returned by \code{brm}}

\item{engine}{A character string, either \code{"stan"} (the default) or \code{"jags"}. Specifies which program should be used to fit the model.
Note that \code{jags} is currently implemented for testing purposes only, does not allow full functionality and is not supported or documented.}

\item{...}{Further arguments to be passed to Stan.}
}
\value{
A vector of character strings specifying parameters of interest for models produced by the \code{brms} package.
}
\description{
Parameters of interest for \code{brms} models
}
\examples{
brm.pars(rating ~ treat + period + carry + (1|subject),
         data = inhaler, family = "cumulative")
}

